@@ -1,6 +1,6 @@
 package Beam::Wire;
 # ABSTRACT: Lightweight Dependency Injection Container
-$Beam::Wire::VERSION = '1.013';
+$Beam::Wire::VERSION = '1.014';
 use strict;
 use warnings;
 
@@ -350,7 +350,8 @@ sub find_refs {
 sub is_meta {
     my ( $self, $arg ) = @_;
     my $prefix = $self->meta_prefix;
-    return !grep { !/^\Q$prefix/ } keys %{$arg};
+    my @keys = keys %{ $arg };
+    return @keys && !grep { !/^\Q$prefix/ } @keys;
 }
 
 sub get_meta_names {
@@ -448,15 +449,86 @@ sub _deprecated {
 sub _load_config {
     my ( $self, $path ) = @_;
     local $Config::Any::YAML::NO_YAML_XS_WARNING = 1;
-    my $loader = Config::Any->load_files( {
-        files  => [$path], use_ext => 1, flatten_to_hash => 1
-    } );
+
+    my $loader;
+    eval {
+        $loader = Config::Any->load_files( {
+            files  => [$path], use_ext => 1, flatten_to_hash => 1
+        } );
+    };
+    if ( $@ ) {
+        Beam::Wire::Exception::Config->throw(
+            file => $self->file,
+            config_error => $@,
+        );
+    }
+
    return "HASH" eq ref $loader ? (values(%{$loader}))[0] : {};
 }
 
+# Check config file for known issues and report
+# Optionally attempt to get all configured items for complete test
+# Intended for use with beam-wire script
+sub validate {
+    my $error_count = 0;
+    my @valid_dependency_nodes = qw( class method args extends lifecycle on config );
+    my ( $self, $instantiate, $show_all_errors ) = @_;
+
+    while ( my ( $name, $v ) = each %{ $self->{config} } ) {
+
+        if ($instantiate) {
+            if ($show_all_errors) {
+                eval {
+                    $self->get($name);
+                };
+                print $@ if $@;
+            }
+            else {
+                $self->get($name);
+            }
+            next;
+        };
+
+        my %config = %{ $self->get_config($name) };
+        %config = $self->merge_config(%config);
+
+        if ( exists $config{value} && ( exists $config{class} || exists $config{extends})) {
+            $error_count++;
+            if ($show_all_errors) {
+                print qq(Invalid config for service '$name': "value" cannot be used with "class" or "extends"\n);
+                next;
+            }
+
+            Beam::Wire::Exception::InvalidConfig->throw(
+                name => $name,
+                file => $self->file,
+                error => '"value" cannot be used with "class" or "extends"',
+            );
+        }
+
+        if ( $config{config} ) {
+            my $conf_path = path( $config{config} );
+            if ( $self->file ) {
+                $conf_path = path( $self->file )->parent->child($conf_path);
+            }
+            %config = %{ $self->_load_config("$conf_path") };
+        }
+
+        unless ( $config{value} || $config{class} || $config{extends} ) {
+            next;
+        }
+
+        if ($config{class}) {
+            eval "require " . $config{class} if $config{class};
+        }
+        #TODO: check method chain & serial
+    }
+    return $error_count;
+}
+
 
 package Beam::Wire::Exception;
-$Beam::Wire::Exception::VERSION = '1.013';
+$Beam::Wire::Exception::VERSION = '1.014';
 use Moo;
 with 'Throwable';
 use Types::Standard qw( :all );
@@ -469,7 +541,7 @@ has error => (
 
 
 package Beam::Wire::Exception::Constructor;
-$Beam::Wire::Exception::Constructor::VERSION = '1.013';
+$Beam::Wire::Exception::Constructor::VERSION = '1.014';
 use Moo;
 use Types::Standard qw( :all );
 extends 'Beam::Wire::Exception';
@@ -481,8 +553,36 @@ has attr => (
 );
 
 
+package Beam::Wire::Exception::Config;
+$Beam::Wire::Exception::Config::VERSION = '1.014';
+use Moo;
+use Types::Standard qw( :all );
+extends 'Beam::Wire::Exception';
+
+has file => (
+    is          => 'ro',
+    isa         => Maybe[InstanceOf['Path::Tiny']],
+);
+
+has config_error => (
+    is => 'ro',
+    isa => Str,
+    required => 1,
+);
+
+has '+error' => (
+    lazy => 1,
+    default => sub {
+        my ( $self ) = @_;
+        return sprintf 'Could not load container file "%s": Error from config parser: %s',
+            $self->file,
+            $self->config_error;
+    },
+);
+
+
 package Beam::Wire::Exception::Service;
-$Beam::Wire::Exception::Service::VERSION = '1.013';
+$Beam::Wire::Exception::Service::VERSION = '1.014';
 use Moo;
 use Types::Standard qw( :all );
 extends 'Beam::Wire::Exception';
@@ -500,7 +600,7 @@ has file => (
 
 
 package Beam::Wire::Exception::NotFound;
-$Beam::Wire::Exception::NotFound::VERSION = '1.013';
+$Beam::Wire::Exception::NotFound::VERSION = '1.014';
 use Moo;
 extends 'Beam::Wire::Exception::Service';
 
@@ -516,7 +616,7 @@ has '+error' => (
 
 
 package Beam::Wire::Exception::InvalidConfig;
-$Beam::Wire::Exception::InvalidConfig::VERSION = '1.013';
+$Beam::Wire::Exception::InvalidConfig::VERSION = '1.014';
 use Moo;
 extends 'Beam::Wire::Exception::Service';
 use overload q{""} => sub {
@@ -542,7 +642,7 @@ Beam::Wire - Lightweight Dependency Injection Container
 
 =head1 VERSION
 
-version 1.013
+version 1.014
 
 =head1 SYNOPSIS
 
@@ -1086,6 +1186,10 @@ The base exception class
 
 An exception creating a Beam::Wire object
 
+=head2 Beam::Wire::Exception::Config
+
+An exception loading the configuration file.
+
 =head2 Beam::Wire::Exception::Service
 
 An exception with service information inside
@@ -1120,6 +1224,22 @@ Al Newkirk <anewkirk@ana.io>
 
 =back
 
+=head1 CONTRIBUTORS
+
+=for stopwords Bruce Armstrong
+
+=over 4
+
+=item *
+
+Bruce Armstrong <bruce@armstronganchor.net>
+
+=item *
+
+Bruce Armstrong <bruce@fortressofgeekdom.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Doug Bell.
